@@ -23,7 +23,7 @@ use vars qw'$VERSION';
 use Carp;
 use Text::BibTeX qw(:metatypes :nodetypes);
 
-$VERSION = 0.1;
+$VERSION = 0.74;
 
 =head1 NAME
 
@@ -37,15 +37,15 @@ Text::BibTeX::Entry - read and parse BibTeX files
    # Text::BibTeX::File, opened for reading and writing (respectively):
 
    # Entry creation/parsing methods:
-   $entry = new Text::BibTeX::Entry;
+   $entry = Text::BibTeX::Entry->new();
    $entry->read ($bibfile);
    $entry->parse ($filename, $filehandle);
    $entry->parse_s ($entry_text);
 
    # or:
-   $entry = new Text::BibTeX::Entry $bibfile;
-   $entry = new Text::BibTeX::Entry $filename, $filehandle;
-   $entry = new Text::BibTeX::Entry $entry_text;
+   $entry = Text::BibTeX::Entry->new( $bibfile );
+   $entry = Text::BibTeX::Entry->new( $filename, $filehandle );
+   $entry = Text::BibTeX::Entry->new( $entry_text );
    
    # Entry query methods
    warn "error in input" unless $entry->parse_ok;
@@ -86,6 +86,7 @@ Text::BibTeX::Entry - read and parse BibTeX files
    $entry->warn ($entry_warning);
    # or:
    $entry->warn ($field_warning, $field);
+   $entry->clone;
 
 =head1 DESCRIPTION
 
@@ -154,16 +155,16 @@ C<$filename> (error handling ignored):
 
    # good ol' fashioned filehandle and GLOB ref
    open (BIBFILE, $filename);
-   $entry = new Text::BibTeX::Entry ($filename, \*BIBFILE);
+   $entry = Text::BibTeX::Entry->new($filename, \*BIBFILE);
 
    # newfangled IO::File thingy
-   $file = new IO::File $filename;
-   $entry = new Text::BibTeX::Entry ($filename, $file);
+   $file = IO::File->new($filename);
+   $entry = Text::BibTeX::Entry->new($filename, $file);
 
 But using a C<Text::BibTeX::File> object is simpler and preferred:
 
-   $file = new Text::BibTeX::File $filename;
-   $entry = new Text::BibTeX::Entry $file;
+   $file  = Text::BibTeX::File->new($filename);
+   $entry = Text::BibTeX::Entry->new($file);
 
 Returns the new object, unless SOURCE is supplied and reading/parsing
 the entry fails (e.g., due to end of file) -- then it returns false.
@@ -212,6 +213,42 @@ sub new
    $self;
 }
 
+=item clone
+
+Clone a Text::BibTeX::Entry object, returning the clone. This re-uses the reference to any
+Text::BibTeX::Structure or Text::BibTeX::File but copies everything else,
+so that the clone can be modified apart from the original.
+
+=cut
+
+sub clone
+{
+  my $self = shift;
+  my $clone = {};
+  # Use the same structure object - won't be changed
+  if ($self->{structure}) {
+    $clone->{structure} = $self->{structure};
+  }
+  # Use the same file object - won't be changed
+  if ($self->{file}) {
+    $clone->{file} = $self->{file}
+  }
+  # These might be changed so make copies
+  $clone->{type}     = $self->{type};
+  $clone->{key}      = $self->{key};
+  $clone->{status}   = $self->{status};
+  $clone->{metatype} = $self->{metatype};
+  $clone->{fields}   = [ map {$_} @{$self->{fields}} ];
+  while (my ($k, $v) = each %{$self->{values}}) {
+    $clone->{values}{$k} = $v;
+  }
+  while (my ($k, $v) = each %{$self->{lines}}) {
+    $clone->{lines}{$k} = $v;
+  }
+  bless $clone, ref($self);
+  return $clone;
+}
+
 =item read (BIBFILE)
 
 Reads and parses an entry from BIBFILE, which must be a
@@ -581,7 +618,7 @@ sub names
 #      unless defined $filename;         # undefined $filename
    for $i (0 .. $#names)
    {
-      $names[$i] = new Text::BibTeX::Name ($names[$i], $filename, $line, $i);
+      $names[$i] = Text::BibTeX::Name->new($names[$i], $filename, $line, $i);
    }
    @names;
 }
